import Modal from "../Modal";
import useConfirmationDialog from "./useConfirmationDialog";

/**
 * @description ConfirmationDialog component displays a confirmation dialog/modal with a message and two buttons: Yes and No.
 * Actions of buttons are definded via hook.
 * State of dialog is based on react context.
 * @returns ConfirmationDialog component
 */
const ConfirmationDialog = () => {
	const {
		isConfirmationDialogVisible,
		handleConfirm,
		handleCancel,
		customModalBoxStyles,
		customModalStyles,
	} = useConfirmationDialog();

	return (
		<>
			{isConfirmationDialogVisible && (
				<Modal
					modalId={"confirmation_dialog"}
					customModalBoxStyles={customModalBoxStyles}
					customModalStyles={customModalStyles}
				>
					<button className="btn btn-primary" onClick={handleConfirm}>
						Yes
					</button>
					<button className="btn btn-secondary" onClick={handleCancel}>
						No
					</button>
				</Modal>
			)}
		</>
	);
};

export default ConfirmationDialog;
